@@ -4,7 +4,7 @@ ZeroMQ REQ-REP wrappers.
 import uuid
 import warnings
 
-from zmq.core import constants
+from zmq import constants
 
 from twisted.internet import defer
 
@@ -63,7 +63,6 @@ class ZmqREQConnection(ZmqConnection):
         @param messageParts: message data
         @type messageParts: C{tuple}
         """
-        print "send", messageParts
         d = defer.Deferred()
         messageId = self._getNextId()
         self._requests[messageId] = d
@@ -76,7 +75,6 @@ class ZmqREQConnection(ZmqConnection):
 
         @param message: message data
         """
-        print "recv", message
         msgId, _, msg = message[0], message[1], message[2:]
         d = self._requests.pop(msgId)
         self._releaseId(msgId)
